@@ -1,5 +1,5 @@
 /* 
- * Copyright 2009-2011 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2018 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,8 +15,8 @@
  *
  */
 
-#ifndef _FILEFORMATFACTORY_H
-#define	_FILEFORMATFACTORY_H
+#ifndef _VOTCA_CSG_FILEFORMATFACTORY_H
+#define	_VOTCA_CSG_FILEFORMATFACTORY_H
 
 #include <string>
 #include <iostream>
@@ -53,5 +53,5 @@ T *FileFormatFactory<T>::Create(const string &file)
 
 }}
 
-#endif	/* _FILEFORMATFACTORY_H */
+#endif	/* _VOTCA_CSG_FILEFORMATFACTORY_H */
 
