@@ -1,5 +1,5 @@
 /* 
- * Copyright 2009-2011 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2018 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,8 +15,8 @@
  *
  */
 
-#ifndef _NEMATICORDER_H
-#define	_NEMATICORDER_H
+#ifndef _VOTCA_CSG_NEMATICORDER_H
+#define	_VOTCA_CSG_NEMATICORDER_H
 
 #include "topology.h"
 #include "topology.h"
@@ -44,5 +44,5 @@ private:
 
 }}
 
-#endif	/* _NEMATICORDER_H */
+#endif	/* _VOTCA_CSG_NEMATICORDER_H */
 
