@@ -1,5 +1,5 @@
 /* 
- * Copyright 2009-2016 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2018 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,8 +19,6 @@
 #define	POTENTIALFUNCTIONCBSPL_H
 
 #include <votca/tools/table.h>
-#include <boost/numeric/ublas/vector.hpp>
-#include <boost/numeric/ublas/matrix.hpp>
 #include <math.h>
 #include "potentialfunction.h"
 
@@ -66,9 +64,9 @@ class PotentialFunctionCBSPL : public PotentialFunction {
 
   int _nbreak;
   double _dr;
-  ub::vector<double> _rbreak;
+  Eigen::VectorXd _rbreak;
 
-  ub::matrix<double> _M;
+  Eigen::MatrixXd _M;
 
 
 };
