@@ -1,5 +1,5 @@
 /* 
- * Copyright 2009-2016 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2018 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,8 +15,8 @@
  *
  */
 
-#ifndef _topology_H
-#define	_topology_H
+#ifndef _VOTCA_CSG_TOPOLOGY_H
+#define	_VOTCA_CSG_TOPOLOGY_H
 
 #include <vector>
 #include <map>
@@ -44,7 +44,7 @@ class ExclusionList;
 
 typedef vector<Molecule *> MoleculeContainer;
 typedef vector<Bead *> BeadContainer;
-typedef vector<BeadType *> BeadTypeContainer;
+typedef vector<shared_ptr<BeadType>> BeadTypeContainer;
 typedef vector<Residue *> ResidueContainer;
 typedef vector<Interaction *> InteractionContainer;
 
@@ -62,9 +62,8 @@ class Topology
 {
 public:
     /// constructor
-    Topology() {
+    Topology() : _time(0.0), _has_vel(false), _has_force(false) {
         _bc = new OpenBox();
-        _has_vel=false;
     }
     virtual ~Topology();
     
@@ -86,7 +85,7 @@ public:
      *
      * The function creates a new bead and adds it to the list of beads.     
      */
-    virtual Bead *CreateBead(byte_t symmetry, string name, BeadType *type, int resnr, double m, double q);
+    virtual Bead *CreateBead(byte_t symmetry, string name, std::weak_ptr<BeadType> type, int resnr, double m, double q);
 
      /**
      * \brief get bead type or create it
@@ -95,7 +94,7 @@ public:
      *
      * Returns an existing bead type or creates one if it doesn't exist yet
      */
-    virtual BeadType *GetOrCreateBeadType(string name);
+    virtual std::weak_ptr<BeadType> GetOrCreateBeadType(string name);
 
     /**
      * \brief creates a new molecule
@@ -194,7 +193,7 @@ public:
     void AddBondedInteraction(Interaction *ic);
     std::list<Interaction *> InteractionsInGroup(const string &group);
     
-    BeadType *getBeadType(const int i) const { return _beadtypes[i]; }
+    std::weak_ptr<BeadType> getBeadType(const int i) { return (_beadtypes[i]); }
     Bead *getBead(const int i) const { return _beads[i]; }
     Residue *getResidue(const int i) const { return _residues[i]; }
     Molecule *getMolecule(const int i) const { return _molecules[i]; }
@@ -411,7 +410,7 @@ protected:
     string _particle_group;
 };
 
-inline Bead *Topology::CreateBead(byte_t symmetry, string name, BeadType *type, int resnr, double m, double q)
+inline Bead *Topology::CreateBead(byte_t symmetry, string name, std::weak_ptr<BeadType> type, int resnr, double m, double q)
 {
     
     Bead *b = new Bead(this, _beads.size(), type, symmetry, name, resnr, m, q);    
@@ -454,5 +453,5 @@ inline void Topology::InsertExclusion(Bead *bead1, iteratable &l) {
 
 #include "interaction.h"
 
-#endif	/* _topology_H */
+#endif	/* _VOTCA_CSG_TOPOLOGY_H */
 
