@@ -1,5 +1,5 @@
-/* 
- * Copyright 2009-2011 The VOTCA Development Team (http://www.votca.org)
+/*
+ * Copyright 2009-2018 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,36 +15,34 @@
  *
  */
 
-#ifndef _TOPOLOGYREADER_H
-#define	_TOPOLOGYREADER_H
+#ifndef _VOTCA_CSG_TOPOLOGYREADER_H
+#define _VOTCA_CSG_TOPOLOGYREADER_H
 
-#include <string>
-#include "topology.h"
 #include "fileformatfactory.h"
+#include "topology.h"
+#include <string>
 
-namespace votca { namespace csg {
+namespace votca {
+namespace csg {
 using namespace votca::tools;
 
 using namespace std;
 
-class TopologyReader
-{
+class TopologyReader {
 public:
-    virtual ~TopologyReader() {}
-    /// open a trejectory file
-    virtual bool ReadTopology(string file, Topology &top) = 0;
-        
-    static void RegisterPlugins(void);
+  virtual ~TopologyReader() {}
+  /// open, read and close topology file
+  virtual bool ReadTopology(string file, Topology &top) = 0;
+
+  static void RegisterPlugins(void);
 };
 
 // important - singleton pattern, make sure factory is created before accessed
-inline FileFormatFactory<TopologyReader> &TopReaderFactory()
-{
-    static FileFormatFactory<TopologyReader> _TopReaderFactory;
-    return _TopReaderFactory;
+inline FileFormatFactory<TopologyReader> &TopReaderFactory() {
+  static FileFormatFactory<TopologyReader> _TopReaderFactory;
+  return _TopReaderFactory;
+}
+}
 }
 
-}}
-
-#endif	/* _TOPOLOGYREADER_H */
-
+#endif // _VOTCA_CSG_TOPOLOGYREADER_H 
