@@ -1,5 +1,5 @@
 /*                                                                                                                                                    
- * Copyright 2009-2011 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2018 The VOTCA Development Team (http://www.votca.org)
  *                                                                                                                                                    
  * Licensed under the Apache License, Version 2.0 (the "License");                                                                                    
  * you may not use this file except in compliance with the License.                                                                                   
@@ -160,7 +160,7 @@ void CsgDensityApp::EvalConfiguration(Topology *top, Topology *top_ref)
                     r = b->getPos() *  _axis;
                 }
                 if (_dens_type=="mass") {
-                  _dist.Process(r, b->getM());
+                  _dist.Process(r, b->getMass());
                 } else {
                   _dist.Process(r, 1.0);
                 }
@@ -184,8 +184,9 @@ void CsgDensityApp::EvalConfiguration(Topology *top, Topology *top_ref)
 void CsgDensityApp::WriteDensity(int nframes, const string &suffix)
 {
   if (_axisname=="r") {
-    _dist.data().y() = _scale/(nframes*_rmax/(double)_nbin *4*M_PI) * element_div( _dist.data().y(),
-                   element_prod(_dist.data().x(), _dist.data().x()));
+    _dist.data().y() = _scale/(nframes*_rmax/(double)_nbin *4*M_PI) * 
+            _dist.data().y().cwiseQuotient(_dist.data().x().cwiseAbs2());
+                  
   } else {
     _dist.data().y() = _scale/((double)nframes * _area * _rmax/ (double)_nbin ) *_dist.data().y();
   }
