@@ -1,5 +1,5 @@
 /* 
- * Copyright 2009-2011 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2018 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -74,7 +74,7 @@ int main(int argc, char** argv)
         po::store(po::parse_command_line(argc, argv, desc), vm);    
         po::notify(vm);
     }
-    catch(po::error err) {
+    catch(po::error& err) {
         cout << "error parsing command line: " << err.what() << endl;
         return -1;
     }
@@ -162,12 +162,12 @@ int main(int argc, char** argv)
         cout << "doing " << type << " fit " << sp_min << ":" << sp_step << ":" << sp_max << endl;
 
         // cut off any values out of fitgrid boundaries (exception: do nothing in case of --nocut)
-        ub::vector<double> x_copy;
-        ub::vector<double> y_copy;
+        Eigen::VectorXd x_copy;
+        Eigen::VectorXd y_copy;
         if (!vm.count("nocut")) {
             // determine vector size
             int minindex=-1, maxindex=-1;
-            for (size_t i=0; i<in.x().size(); i++) {
+            for (int i=0; i<in.x().size(); i++) {
                 if(in.x(i)<sp_min) {
                     minindex = i;
                 }
@@ -177,8 +177,8 @@ int main(int argc, char** argv)
             }
             // copy data values in [sp_min,sp_max] into new vectors
             minindex++;
-            x_copy = ub::zero_vector<double>(maxindex-minindex+1);
-            y_copy = ub::zero_vector<double>(maxindex-minindex+1);
+            x_copy = Eigen::VectorXd::Zero(maxindex-minindex+1);
+            y_copy = Eigen::VectorXd::Zero(maxindex-minindex+1);
             for (int i=minindex; i<=maxindex; i++) {
                 x_copy(i-minindex) = in.x(i);
                 y_copy(i-minindex) = in.y(i);
@@ -227,15 +227,15 @@ int main(int argc, char** argv)
         out.set_comment(comment);
     }
     out.y() = out.y();
-    out.flags() = ub::scalar_vector<double>(out.flags().size(), 'o');
+    out.flags() = std::vector<char>(out.flags().size(), 'o');
 
     der.GenerateGridSpacing(min, max, step);
-    der.flags() = ub::scalar_vector<double>(der.flags().size(), 'o');
+    der.flags() = std::vector<char>(der.flags().size(), 'o');
 
-    unsigned int i=0;
+    int i=0;
     for(i=0; out.x(i) < in.x(0) && i<out.size(); ++i);
 
-    unsigned int j=0;
+    int j=0;
     for(;i < out.size(); ++i) {
         for(; j < in.size(); ++j)
             if(in.x(j) >= out.x(i)  || fabs(in.x(j)-out.x(i) ) < 1e-12) // fix for precison errors
