@@ -1,5 +1,5 @@
 /* 
- * Copyright 2009-2011 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2018 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -22,9 +22,11 @@
 #include <votca/tools/rangeparser.h>
 #include <votca/csg/beadlist.h>
 #include <votca/csg/nblistgrid.h>
+#include <votca/csg/nblistgrid_3body.h>
 #include "csg_stat_imc.h"
 #include <votca/csg/imcio.h>
 
+
 namespace votca { namespace csg {
 
 Imc::Imc()
@@ -59,7 +61,7 @@ void Imc::Initialize()
         i->_is_bonded = false;
     }
 
-    // initialize non-bonded structures
+    // initialize bonded structures
    for (list<Property*>::iterator iter = _bonded.begin();
         iter != _bonded.end(); ++iter) {
             interaction_t *i = AddInteraction(*iter);
@@ -84,25 +86,51 @@ void Imc::BeginEvaluate(Topology *top, Topology *top_atom)
         string name = (*iter)->get("name").value();
 
         interaction_t &i = *_interactions[name];
+        
+        //Preleminary: Quickest way to incorporate 3 body correlations
+        if (i._threebody){
+            
+            // generate the bead lists
+            BeadList beads1, beads2, beads3;
 
-        // generate the bead lists
-        BeadList beads1, beads2;
+            beads1.Generate(*top, (*iter)->get("type1").value());
+            beads2.Generate(*top, (*iter)->get("type2").value());
+            beads3.Generate(*top, (*iter)->get("type3").value());
 
-        beads1.Generate(*top, (*iter)->get("type1").value());
-        beads2.Generate(*top, (*iter)->get("type2").value());
+            if(beads1.size() == 0)
+                throw std::runtime_error("Topology does not have beads of type \"" + (*iter)->get("type1").value() + "\"\n"
+                        "This was specified in type1 of interaction \"" + name+ "\"");
+            if(beads2.size() == 0)
+                throw std::runtime_error("Topology does not have beads of type \"" + (*iter)->get("type2").value() + "\"\n"
+                        "This was specified in type2 of interaction \"" + name + "\"");
+            if(beads3.size() == 0)
+                throw std::runtime_error("Topology does not have beads of type \"" + (*iter)->get("type3").value() + "\"\n"
+                        "This was specified in type3 of interaction \"" + name + "\"");             
+        }
+        //2body
+        if (!i._threebody){
+
+            // generate the bead lists
+            BeadList beads1, beads2;
+
+            beads1.Generate(*top, (*iter)->get("type1").value());
+            beads2.Generate(*top, (*iter)->get("type2").value());
+
+            if(beads1.size() == 0)
+                throw std::runtime_error("Topology does not have beads of type \"" + (*iter)->get("type1").value() + "\"\n"
+                        "This was specified in type1 of interaction \"" + name+ "\"");
+            if(beads2.size() == 0)
+                throw std::runtime_error("Topology does not have beads of type \"" + (*iter)->get("type2").value() + "\"\n"
+                        "This was specified in type2 of interaction \"" + name + "\"");
+
+            // calculate normalization factor for rdf
+            if ((*iter)->get("type1").value() == (*iter)->get("type2").value())
+                i._norm = 1. / (beads1.size()*(beads2.size()) / 2.);
+            else
+                i._norm = 1. / (beads1.size() * beads2.size());            
+        }
 
-        if(beads1.size() == 0)
-            throw std::runtime_error("Topology does not have beads of type \"" + (*iter)->get("type1").value() + "\"\n"
-                    "This was specified in type1 of interaction \"" + name+ "\"");
-        if(beads2.size() == 0)
-            throw std::runtime_error("Topology does not have beads of type \"" + (*iter)->get("type2").value() + "\"\n"
-                    "This was specified in type2 of interaction \"" + name + "\"");
-        // calculate normalization factor for rdf
 
-        if ((*iter)->get("type1").value() == (*iter)->get("type2").value())
-            i._norm = 1. / (beads1.size()*(beads2.size()) / 2.);
-        else
-            i._norm = 1. / (beads1.size() * beads2.size());
     }
 
     for (list<Property*>::iterator iter = _bonded.begin();
@@ -135,11 +163,23 @@ Imc::interaction_t *Imc::AddInteraction(Property *p)
     i->_max = p->get("max").as<double>();
     i->_norm = 1.0;
     i->_p=p;
-    
-    // initialize the current and average histogram
-    int n = (int)((i->_max - i->_min) / i->_step + 1.000000001);
 
-    i->_average.Initialize(i->_min, i->_max+i->_step, n);
+    //if option threebody does not exist, replace it by default of 0    
+    i->_threebody = p->ifExistsReturnElseReturnDefault<bool>("threebody",0); 	
+	
+    //if option force does not exist, replace it by default of 0	    
+    i->_force = p->ifExistsReturnElseReturnDefault<bool>("force",0);            
+
+    //if option cut does not exist, replace it by default of 0.37 nm
+    i->_cut = p->ifExistsReturnElseReturnDefault<double>("cut",0.37);
+
+    // initialize the current and average histogram
+    int n = static_cast<int>((i->_max - i->_min) / i->_step + 1.000000001);
+
+    i->_average.Initialize(i->_min, i->_max, n);
+    if (i->_force){
+        i->_average_force.Initialize(i->_min, i->_max, n);
+    }
     
     return i;
 }
@@ -186,11 +226,16 @@ void Imc::ClearAverages()
     map<string, group_t *>::iterator group_iter;
     
     _nframes = 0;
-    for (ic_iter = _interactions.begin(); ic_iter != _interactions.end(); ++ic_iter)
-        ic_iter->second->_average.Clear();    
+    for (ic_iter = _interactions.begin(); ic_iter != _interactions.end(); ++ic_iter){
+        ic_iter->second->_average.Clear();
+        if (ic_iter->second->_force){
+            ic_iter->second->_average_force.Clear();
+        }
+    }
     
-    for (group_iter = _groups.begin(); group_iter != _groups.end(); ++group_iter)
-        group_iter->second->_corr.clear();      
+    for (group_iter = _groups.begin(); group_iter != _groups.end(); ++group_iter){
+        group_iter->second->_corr.setZero(); 
+    }
 }
 
 class IMCNBSearchHandler {
@@ -215,16 +260,11 @@ void Imc::Worker::DoNonbonded(Topology *top)
         string name = (*iter)->get("name").value();
         
         interaction_t &i = *_imc->_interactions[name];
-        
-        // generate the bead lists
-        BeadList beads1, beads2;
-        
-        beads1.Generate(*top, (*iter)->get("type1").value());
-        beads2.Generate(*top, (*iter)->get("type2").value());
-               
-        // generate the neighbour list
-        NBList *nb;
 
+        // clear the current histogram
+        _current_hists[i._index].Clear();
+        _current_hists_force[i._index].Clear();      
+        
         bool gridsearch=true;
 
         if(_imc->_options.exists("cg.nbsearch")) {
@@ -233,34 +273,132 @@ void Imc::Worker::DoNonbonded(Topology *top)
             else if(_imc->_options.get("cg.nbsearch").as<string>() == "simple")
                 gridsearch=false;
             else throw std::runtime_error("cg.nbsearch invalid, can be grid or simple");
+        }    
+        
+        //Preleminary: Quickest way to incorporate 3 body correlations
+        if (i._threebody){
+            
+            // generate the bead lists
+            BeadList beads1, beads2, beads3;
+        
+            beads1.Generate(*top, (*iter)->get("type1").value());
+            beads2.Generate(*top, (*iter)->get("type2").value());            
+            beads3.Generate(*top, (*iter)->get("type3").value());            
+            
+            // generate the neighbour list    
+            NBList_3Body *nb; 
+ 
+            if(gridsearch) 
+                nb = new NBListGrid_3Body();            
+            else
+                nb = new NBList_3Body();                        
+            
+            nb->setCutoff(i._cut); // implement different cutoffs for different interactions!
+            //Here, a is the distance between two beads of a triple, where the 3-body interaction is zero              
+            
+            //check if type1 and type2 are the same
+            if ((*iter)->get("type1").value() == (*iter)->get("type2").value()){
+                //if all three types are the same
+                if ((*iter)->get("type2").value() == (*iter)->get("type3").value()){        
+                    nb->Generate(beads1, true);
+                }
+                //if type2 and type3 are different, use the Generate function for 2 bead types
+                if ((*iter)->get("type2").value() != (*iter)->get("type3").value()){           
+                    nb->Generate(beads1, beads3, true); 
+                }
+            }
+            //if type1 != type2
+            if ((*iter)->get("type1").value() != (*iter)->get("type2").value()){   
+                //if the last two types are the same, use Generate function with them as the first two bead types
+                //Neighborlist_3body is constructed in a way that the two equal bead types have two be the first 2 types
+                if ((*iter)->get("type2").value() == (*iter)->get("type3").value()){
+                    nb->Generate(beads1, beads2, true);         
+                }
+                if ((*iter)->get("type2").value() != (*iter)->get("type3").value()){
+                    //type1 = type3 !=type2
+                    if ((*iter)->get("type1").value() == (*iter)->get("type3").value()){          
+                        nb->Generate(beads2, beads1, true);
+                    }
+                    //type1 != type2 != type3
+                    if ((*iter)->get("type1").value() != (*iter)->get("type3").value()){              
+                        nb->Generate(beads1, beads2, beads3, true);
+                    }
+                }
+            }            
+            
+            NBList_3Body::iterator triple_iter;
+            // iterate over all triples
+            for (triple_iter = nb->begin(); triple_iter != nb->end(); ++triple_iter){
+                vec rij  = (*triple_iter)->r12();
+                vec rik  = (*triple_iter)->r13();
+                double var = acos(rij*rik/sqrt((rij*rij) * (rik*rik))); 
+                _current_hists[i._index].Process(var);               
+            }
+
+            delete nb;   
+            
         }
-        if(gridsearch)
-            nb = new NBListGrid();
-        else
-            nb = new NBList();
+        //2body interaction
+        if (!i._threebody){
+            
+            // generate the bead lists
+            BeadList beads1, beads2;
+        
+            beads1.Generate(*top, (*iter)->get("type1").value());
+            beads2.Generate(*top, (*iter)->get("type2").value());
+               
+            // generate the neighbour list
+            NBList *nb;
 
-        nb->setCutoff(i._max + i._step);
-                
-        // clear the current histogram
-        _current_hists[i._index].Clear();
+            if(gridsearch)
+                nb = new NBListGrid();
+            else
+                nb = new NBList();
 
-        IMCNBSearchHandler h(&(_current_hists[i._index]));
+            nb->setCutoff(i._max + i._step);
 
-        nb->SetMatchFunction(&h, &IMCNBSearchHandler::FoundPair);
+            IMCNBSearchHandler h(&(_current_hists[i._index]));
 
-        // is it same types or different types?
-        if((*iter)->get("type1").value() == (*iter)->get("type2").value())
-            nb->Generate(beads1);
-        else
-            nb->Generate(beads1, beads2);
+            nb->SetMatchFunction(&h, &IMCNBSearchHandler::FoundPair);
 
-        // process all pairs
-        /*NBList::iterator pair_iter;
-        for(pair_iter = nb->begin(); pair_iter!=nb->end();++pair_iter) {
-                _current_hists[i._index].Process((*pair_iter)->dist());
-        }*/
+            // is it same types or different types?
+            if((*iter)->get("type1").value() == (*iter)->get("type2").value())
+                nb->Generate(beads1);
+            else
+                nb->Generate(beads1, beads2);
 
-        delete nb;
+            delete nb;
+
+            //if one wants to calculate the mean force
+            if (i._force){
+                if(gridsearch)
+                    nb = new NBListGrid();
+                else
+                    nb = new NBList();            
+         
+                nb->setCutoff(i._max + i._step);
+            
+                // is it same types or different types?
+                if((*iter)->get("type1").value() == (*iter)->get("type2").value())
+                    nb->Generate(beads1);
+                else
+                    nb->Generate(beads1, beads2);            
+
+                //process all pairs to calculate the projection of the 
+                //mean force on bead 1 on the pair distance: F1 * r12
+                NBList::iterator pair_iter;
+                for(pair_iter = nb->begin(); pair_iter!=nb->end();++pair_iter) {
+                    vec F2 = (*pair_iter)->second->getF();
+                    vec F1 = (*pair_iter)->first->getF();                    
+                    vec r12 = (*pair_iter)->r();
+                    r12.normalize();
+                    double var = (*pair_iter)->dist();
+                    double scale = 0.5*(F2-F1)*r12;
+                    _current_hists_force[i._index].Process(var,scale);
+                }
+                delete nb;                 
+            }           
+        }
     }    
 }
 
@@ -322,8 +460,7 @@ void Imc::InitializeGroups()
         group_matrix &M = grp->_corr;
         
         // initialize matrix with zeroes
-        M.resize(n,n);
-        M = ub::zero_matrix<double>(n, n);
+        M=Eigen::MatrixXd::Zero(n,n);
         
         // now create references to the sub matrices
         int i, j;
@@ -338,7 +475,7 @@ void Imc::InitializeGroups()
                 int n2 = (*i2)->_average.getNBins();
                 
                 // create matrix proxy with sub-matrix
-                pair_matrix corr(M, ub::range(i, i+n1), ub::range(j, j+n2));
+                pair_matrix corr=M.block(i,j,n1,n2);
                 // add the pair
                 grp->_pairs.push_back(pair_t(*i1, *i2, i, j, corr));
                 j+=n2;
@@ -358,15 +495,11 @@ void Imc::DoCorrelations(Imc::Worker *worker) {
         group_t *grp = (*group_iter).second;      
         // update correlation for all pairs
         for (pair = grp->_pairs.begin(); pair != grp->_pairs.end(); ++pair) {
-            ub::vector<double> &a = worker->_current_hists[pair->_i1->_index].data().y();
-            ub::vector<double> &b = worker->_current_hists[pair->_i2->_index].data().y();
+            Eigen::VectorXd &a = worker->_current_hists[pair->_i1->_index].data().y();
+            Eigen::VectorXd &b = worker->_current_hists[pair->_i2->_index].data().y();
             pair_matrix &M = pair->_corr;
 
-            // M_ij += a_i*b_j
-            //for(int i=0; i<M.size1(); ++i)
-            //    for(int j=i; j<M.size2(); ++j)
-            //        M(i,j) = ((((double)_nframes-1.0)*M(i,j)) + (a(i)*b(j)))/(double)_nframes;
-            M = ((((double)_nframes-1.0)*M) + ub::outer_prod(a, b))/(double)_nframes;
+            M = ((((double)_nframes-1.0)*M) + a*b.transpose())/(double)_nframes;
         }
     }
 }
@@ -382,30 +515,72 @@ void Imc::WriteDist(const string &suffix)
         // calculate the rdf
         Table &t = iter->second->_average.data();            
         Table dist(t);
+        
+        //if no average force calculation, dummy table
+        Table force;
+        //if average force calculation, table force contains force data
+        if (iter->second->_force){
+            Table &f = iter->second->_average_force.data();
+            force = f;
+        }    
+        
         if(!iter->second->_is_bonded) {
-            // normalization is calculated using exact shell volume (difference of spheres)
-            for(unsigned int i=0; i<dist.y().size(); ++i) {
-                double x1 = dist.x()[i] - 0.5*iter->second->_step;
-                double x2 = x1 + iter->second->_step;
-                if(x1<0) {
-                    dist.y()[i]=0;
-                }
-                else {
-                    dist.y()[i] = _avg_vol.getAvg()*iter->second->_norm *
-                        dist.y()[i]/(4./3.*M_PI*(x2*x2*x2 - x1*x1*x1));                
-                }
+            //Quickest way to incorporate 3 body correlations
+            if (iter->second->_threebody){
+	        // \TODO normalize bond and angle differently....
+                double norm=dist.y().cwiseAbs().sum();
+                if ( norm > 0 ) {
+                    dist.y() = iter->second->_norm * dist.y() / ( norm * iter->second->_step );
+                }           
+                
             }
+            
+            //2body
+            if (!iter->second->_threebody){
+                //force normalization
+                //normalize by number of pairs found at a specific distance
+                for(unsigned int i=0; i<force.y().size(); ++i) {
+                    //check if any number of pairs has been found at this distance, then normalize
+                    if (dist.y()[i]!=0){
+                        force.y()[i]/=dist.y()[i];
+                    }
+                    //else set to zero
+                    else{
+                        force.y()[i]=0;
+                    }
+                }                
+                
+                // normalization is calculated using exact shell volume (difference of spheres)
+                for(unsigned int i=0; i<dist.y().size(); ++i) {
+                    double x1 = dist.x()[i] - 0.5*iter->second->_step;
+                    double x2 = x1 + iter->second->_step;
+                    if(x1<0) {
+                        dist.y()[i]=0;
+                    }
+                    else {
+                        dist.y()[i] = _avg_vol.getAvg()*iter->second->_norm *
+                            dist.y()[i]/(4./3.*M_PI*(x2*x2*x2 - x1*x1*x1));                
+                    }
+                }                
+            }
+
         }
         else {
 	    // \TODO normalize bond and angle differently....
-            double norm=ub::norm_1(dist.y());
+            double norm=dist.y().cwiseAbs().sum();
             if ( norm > 0 ) {
-              dist.y() = iter->second->_norm * dist.y() / ( norm * iter->second->_step );
+                dist.y() = iter->second->_norm * dist.y() / ( norm * iter->second->_step );
             }
         }
         
         dist.Save((iter->first) + suffix);
         cout << "written " << (iter->first) + suffix << "\n";
+
+        //preliminary
+        if (iter->second->_force){
+            force.Save((iter->first) + ".force.new");
+            cout << "written " << (iter->first) + ".force.new" << "\n";            
+        } 
     }
 }
 
@@ -428,13 +603,13 @@ void Imc::WriteIMCData(const string &suffix) {
         list<interaction_t *>::iterator iter;
         
         // number of total bins for all interactions in group is matrix dimension
-        int n=grp->_corr.size1();
+        int n=grp->_corr.rows();
                 
         // build full set of equations + copy some data to make
         // code better to read
         group_matrix gmc(grp->_corr);
-        ub::vector<double> dS(n);
-        ub::vector<double> r(n);
+        Eigen::VectorXd dS(n);
+        Eigen::VectorXd r(n);
         // the next two variables are to later extract the individual parts
         // from the whole data after solving equations
         vector<RangeParser> ranges; // sizes of the individual interactions
@@ -447,12 +622,10 @@ void Imc::WriteIMCData(const string &suffix) {
             interaction_t *ic = *iter;
             
             // sub vector for dS
-            ub::vector_range< ub::vector<double> > sub_dS(dS, 
-                    ub::range(n, n + ic->_average.getNBins()));
+            Eigen::VectorBlock< Eigen::VectorXd > sub_dS=dS.segment(n,ic->_average.getNBins());
             
             // sub vector for r
-            ub::vector_range< ub::vector<double> > sub_r(r, 
-                    ub::range(n, n + ic->_average.getNBins()));
+           Eigen::VectorBlock< Eigen::VectorXd > sub_r=r.segment(n,ic->_average.getNBins());
             
             // read in target and calculate dS
             CalcDeltaS(ic, sub_dS);
@@ -461,7 +634,6 @@ void Imc::WriteIMCData(const string &suffix) {
             sub_r = ic->_average.data().x();
             
             // save size
-
             RangeParser rp;
             int end = begin  + ic->_average.getNBins() -1;
             rp.Add(begin, end);
@@ -482,25 +654,20 @@ void Imc::WriteIMCData(const string &suffix) {
             interaction_t *i2 = pair->_i2;
             
             // make reference to <S_i>
-            ub::vector<double> &a = i1->_average.data().y();
+           Eigen::VectorXd &a = i1->_average.data().y();
             // make reference to <S_j>
-            ub::vector<double> &b = i2->_average.data().y();
+            Eigen::VectorXd &b = i2->_average.data().y();
             
             int i=pair->_offset_i;
             int j=pair->_offset_j;
             int n1=i1->_average.getNBins();
             int n2=i2->_average.getNBins();
             
-            // sub matrix for these two interactions
-            // we only need to take care about one sub-matrix and not the mirrored
-            // one since ublas makes sure the matrix is symmetric
-            pair_matrix M(gmc, ub::range(i, i+n1),
-                               ub::range(j, j+n2));
-            // A_ij = -(<a_i*a_j>  - <a_i>*<b_j>)
-            //for(i=0; i<M.size1(); ++i)
-            //    for(j=i; j<M.size2(); ++j)
-            //        M(i,j) = -(M(i,j) - a(i)*b(j));
-            M = -(M - ub::outer_prod(a, b));
+          
+            pair_matrix M=gmc.block(i,j,n1,n2);
+            M = -(M - a*b.transpose());
+            //matrix is symmetric
+            gmc.block(j,i,n2,n1)=M.transpose().eval();
         }
         
         imcio_write_dS(grp_name + suffix + ".imc", r, dS);
@@ -511,7 +678,7 @@ void Imc::WriteIMCData(const string &suffix) {
 }
 
 // calculate deviation from target vectors
-void Imc::CalcDeltaS(interaction_t *interaction, ub::vector_range< ub::vector<double> > &dS)
+void Imc::CalcDeltaS(interaction_t *interaction, Eigen::VectorBlock< Eigen::VectorXd > &dS)
 {
     const string &name = interaction->_p->get("name").as<string>();
                 
@@ -540,6 +707,8 @@ void Imc::CalcDeltaS(interaction_t *interaction, ub::vector_range< ub::vector<do
 
 void Imc::WriteIMCBlock(const string &suffix)
 {
+  
+
     if(!_do_imc) return;
     //map<string, interaction_t *>::iterator ic_iter;
     map<string, group_t *>::iterator group_iter;
@@ -551,13 +720,13 @@ void Imc::WriteIMCBlock(const string &suffix)
         list<interaction_t *>::iterator iter;
 
         // number of total bins for all interactions in group is matrix dimension
-        int n=grp->_corr.size1();
+        int n=grp->_corr.rows();
 
         // build full set of equations + copy some data to make
         // code better to read
         group_matrix gmc(grp->_corr);
-        ub::vector<double> dS(n);
-        ub::vector<double> r(n);
+        Eigen::VectorXd dS(n);
+        Eigen::VectorXd r(n);
         // the next two variables are to later extract the individual parts
         // from the whole data after solving equations
         vector<int> sizes; // sizes of the individual interactions
@@ -569,12 +738,10 @@ void Imc::WriteIMCBlock(const string &suffix)
             interaction_t *ic = *iter;
 
             // sub vector for dS
-            ub::vector_range< ub::vector<double> > sub_dS(dS,
-                    ub::range(n, n + ic->_average.getNBins()));
-
+            Eigen::VectorBlock< Eigen::VectorXd > sub_dS=dS.segment(n,ic->_average.getNBins());
+            
             // sub vector for r
-            ub::vector_range< ub::vector<double> > sub_r(r,
-                    ub::range(n, n + ic->_average.getNBins()));
+           Eigen::VectorBlock< Eigen::VectorXd > sub_r=r.segment(n,ic->_average.getNBins());
 
             // read in target and calculate dS
             sub_dS = ic->_average.data().y();
@@ -597,7 +764,7 @@ void Imc::WriteIMCBlock(const string &suffix)
         if(!out_dS)
             throw runtime_error(string("error, cannot open file ") + name_dS);
 
-        for(size_t i=0; i<dS.size(); ++i) {
+        for(int i=0; i<dS.size(); ++i) {
             out_dS << r[i] << " " << dS[i] << endl;
         }
 
@@ -613,8 +780,8 @@ void Imc::WriteIMCBlock(const string &suffix)
         if(!out_cor)
             throw runtime_error(string("error, cannot open file ") + name_cor);
 
-        for(group_matrix::size_type i=0; i<grp->_corr.size1(); ++i) {
-            for(group_matrix::size_type j=0; j<grp->_corr.size2(); ++j) {
+        for(int i=0; i<grp->_corr.rows(); ++i) {
+            for(int j=0; j<grp->_corr.cols(); ++j) {
                 out_cor << grp->_corr(i, j) << " ";
             }
             out_cor << endl;
@@ -631,6 +798,7 @@ CsgApplication::Worker *Imc::ForkWorker()
     map<string, interaction_t *>::iterator ic_iter;
 
     worker->_current_hists.resize(_interactions.size());
+    worker->_current_hists_force.resize(_interactions.size());
     worker->_imc = this;
 
     for (ic_iter = _interactions.begin(); ic_iter != _interactions.end(); ++ic_iter) {
@@ -639,6 +807,13 @@ CsgApplication::Worker *Imc::ForkWorker()
         i->_average.getMin(),
         i->_average.getMax(),
         i->_average.getNBins());
+        //preliminary
+        if (ic_iter->second->_force){
+            worker->_current_hists_force[i->_index].Initialize(
+            i->_average_force.getMin(),
+            i->_average_force.getMax(),
+            i->_average_force.getNBins());          
+        }
     }
     return worker;
 }
@@ -657,6 +832,11 @@ void Imc::MergeWorker(CsgApplication::Worker* worker_)
         interaction_t *i=ic_iter->second;
         i->_average.data().y() = (((double)_nframes-1.0)*i->_average.data().y()
             + worker->_current_hists[i->_index].data().y())/(double)_nframes;
+        //preliminary
+        if (i->_force){
+            i->_average_force.data().y() = (((double)_nframes-1.0)*i->_average_force.data().y()
+                + worker->_current_hists_force[i->_index].data().y())/(double)_nframes;
+        }       
     }
 
         // update correlation matrices
